/*!
 * arr-diff <https://github.com/jonschlinkert/arr-diff>
 *
 * Copyright (c) 2014 Jon Schlinkert, contributors.
 * Licensed under the MIT License
 */

'use strict';

/**
 * Return the difference between two arrays.
 *
 * ```js
 * var a = ['a', 'b', 'c', 'd'];
 * var b = ['b', 'c'];
 *
 * console.log(difference(a, b))
 * //=> ['a', 'd']
 * ```
 *
 * @param  {Array} `a`
 * @param  {Array} `b`
 * @return {Array}
 */

module.exports = function difference(a, b) {
  if (a == null) {
    return [];
  }

  if (!Array.isArray(b)) {
    return a;
  }

  if (!Array.isArray(a)) {
    throw new TypeError();
  }

  var alen = a.length;
  var blen = b.length;
  var arr = [];

  for (var i = 0; i < alen; i++) {
    var key = a[i];

    if (b.indexOf(key) === -1) {
      arr.push(key);
    }
  }

  return arr;
};

